@@ -10,19 +10,18 @@ PUBKEY_CACHE = {}
 class Passage:
 
     """
-    When a Passage object is created, attempt to load the public key from the environment variable.
-    This is currently required.
+    When a Passage object is created, fetch the public key from the cache or make an API request to get it
     """
-    def __init__(self, app_handle, api_key=""):
-        self.app_handle = app_handle
+    def __init__(self, app_id, api_key=""):
+        self.app_id = app_id
         self.passage_apikey = api_key
 
         # if the pubkey exists in the cache, use that to avoid making requests
-        if app_handle in PUBKEY_CACHE.keys():
-            self.passage_pubkey = PUBKEY_CACHE[app_handle]
+        if app_id in PUBKEY_CACHE.keys():
+            self.passage_pubkey = PUBKEY_CACHE[app_id]
         else:
-            self.passage_pubkey = fetchPublicKey(app_handle)
-            PUBKEY_CACHE[app_handle] = self.passage_pubkey
+            self.passage_pubkey = fetchPublicKey(app_id)
+            PUBKEY_CACHE[app_id] = self.passage_pubkey
     
     """
     Authenticate a Flask request that uses Passage for authentication.
@@ -43,23 +42,23 @@ class Passage:
             raise PassageError("JWT is not valid: " + str(e))
 
     """
-    Use Passage API to get info for a user, look up by user handle
+    Use Passage API to get info for a user, look up by user ID
     """ 
-    def getUserInfo(self, user_handle):
+    def getUserInfo(self, user_id):
         # if no api key, fail
         if self.passage_apikey == "":
             raise PassageError("No Passage API key provided.")
 
         header = {"Authorization": "Bearer " + self.passage_apikey}
         try:
-            url = "https://api.passage.id/v1/app/" + self.app_handle + "/users/" + user_handle
+            url = "https://api.passage.id/v1/apps/" + self.app_id + "/users/" + user_id
             r = requests.get(url, headers=header)
 
             if r.status_code != 200:
                 # get error message
-                message = r.json()["message"]
+                message = r.json()
                 raise PassageError("Failed request to get user data: " + message)
-            return r.json()
+            return r.json()["user"]
         except Exception as e:
             raise PassageError("Could not fetch user data")
 
@@ -67,35 +66,34 @@ class Passage:
     """
     Get instance of Passage User
     """
-    def getPassageUser(self, user_handle):
-        return Passage.PassageUser(self, user_handle)
+    def getUser(self, user_id):
+        return Passage.PassageUser(self, user_id)
 
     """
     Inner class represesnting a Passage User. 
     """
     class PassageUser:
 
-        def __init__(self, psg, user_handle):
+        def __init__(self, psg, user_id):
             self.psg = psg
-            self.handle = user_handle
+            self.id = user_id
 
-            data = self.psg.getUserInfo(self.handle)
+            data = self.psg.getUserInfo(self.id)
             # set the individual fields 
             self.email = data["email"]
             self.active = data["active"]
             self.email_verified = data["email_verified"]
 
             try:
-                self.start_date = datetime.strptime(data["start_date"],"%Y-%m-%dT%H:%M:%S.%fZ")
+                self.created_at = datetime.strptime(data["created_at"],"%Y-%m-%dT%H:%M:%S.%fZ")
             except:
-                self.start_date = datetime.strptime(data["start_date"],"%Y-%m-%dT%H:%M:%SZ")
+                self.created_at = datetime.strptime(data["created_at"],"%Y-%m-%dT%H:%M:%SZ")
 
             try:
-                self.last_login_date = datetime.strptime(data["last_login_date"],"%Y-%m-%dT%H:%M:%S.%fZ")
+                self.last_login_at = datetime.strptime(data["last_login_at"],"%Y-%m-%dT%H:%M:%S.%fZ")
             except:
-                self.last_login_date = datetime.strptime(data["last_login_date"],"%Y-%m-%dT%H:%M:%SZ")
+                self.last_login_at = datetime.strptime(data["last_login_at"],"%Y-%m-%dT%H:%M:%SZ")
 
-            self.password = data["password"]
             self.webauthn = data["webauthn"]
             self.webauthn_devices = data["webauthn_devices"]
             events = data["recent_events"]
@@ -108,13 +106,11 @@ class Passage:
 class PassageEvent:
 
     def __init__(self, event):
-        self.email = event["email"]
-        self.event_type = event["event_type"]
-        self.handle = event["handle"]
-        self.status = event["status"]
+        self.event_type = event["type"]
+        self.id = event["id"]
 
         try:
-            self.timestamp = datetime.strptime(event["timestamp"],"%Y-%m-%dT%H:%M:%S.%fZ")
+            self.timestamp = datetime.strptime(event["created_at"],"%Y-%m-%dT%H:%M:%S.%fZ")
         except:
-             self.timestamp = datetime.strptime(event["timestamp"],"%Y-%m-%dT%H:%M:%SZ")
+             self.timestamp = datetime.strptime(event["created_at"],"%Y-%m-%dT%H:%M:%SZ")
            
\ No newline at end of file
